@@ -3,11 +3,16 @@ import {
   JupyterFrontEnd,
   JupyterFrontEndPlugin
 } from '@jupyterlab/application';
-import { MainAreaWidget, WidgetTracker } from '@jupyterlab/apputils';
+import {
+  Dialog,
+  MainAreaWidget,
+  showDialog,
+  WidgetTracker
+} from '@jupyterlab/apputils';
 import { FileBrowser, IFileBrowserFactory } from '@jupyterlab/filebrowser';
 import { ILauncher } from '@jupyterlab/launcher';
 import { INotebookTracker } from '@jupyterlab/notebook';
-import { Contents } from '@jupyterlab/services';
+import { Contents, ServerConnection } from '@jupyterlab/services';
 import { ITranslator } from '@jupyterlab/translation';
 
 import AdvancedOptions from './advanced-options';
@@ -20,6 +25,7 @@ import { SchedulerService } from './handler';
 import { IJobsModel, emptyCreateJobModel, JobsView } from './model';
 import { NotebookJobsPanel } from './notebook-jobs-panel';
 import { Scheduler } from './tokens';
+import { SERVER_EXTENSION_404_JSX } from './util/errors';
 import { MakeNameValid } from './util/job-name-validation';
 
 export namespace CommandIDs {
@@ -123,10 +129,29 @@ async function activatePlugin(
   advancedOptions: Scheduler.IAdvancedOptions,
   launcher: ILauncher | null
 ): Promise<void> {
-  const { commands } = app;
   const trans = translator.load('jupyterlab');
-  const fileBrowserTracker = browserFactory.tracker;
   const api = new SchedulerService({});
+
+  // Call API to verify that the server extension is actually installed
+  try {
+    await api.getJobs({ max_items: 0 });
+  } catch (e: unknown) {
+    // in case of 404, show missing server extension dialog and return
+    if (
+      e instanceof ServerConnection.ResponseError &&
+      e.response.status === 404
+    ) {
+      showDialog({
+        title: trans.__('Jupyter Scheduler server extension not found'),
+        body: SERVER_EXTENSION_404_JSX,
+        buttons: [Dialog.okButton()]
+      }).catch(console.warn);
+      return;
+    }
+  }
+
+  const { commands } = app;
+  const fileBrowserTracker = browserFactory.tracker;
   const widgetTracker = new WidgetTracker<MainAreaWidget<NotebookJobsPanel>>({
     namespace: 'jupyterlab-scheduler'
   });
