@@ -1,4 +1,4 @@
-import React, { useEffect, useState } from 'react';
+import React, { useCallback, useEffect, useState } from 'react';
 
 import { JupyterFrontEnd } from '@jupyterlab/application';
 import {
@@ -16,12 +16,13 @@ import { Scheduler } from '../../tokens';
 import { JobDetail } from './job-detail';
 import { JobDefinition } from './job-definition';
 
-import Stack from '@mui/material/Stack';
 import {
+  Alert,
   Box,
   Breadcrumbs,
   CircularProgress,
   Link,
+  Stack,
   Typography
 } from '@mui/material';
 import { Heading } from '../../components/heading';
@@ -57,26 +58,35 @@ export function DetailView(props: IDetailViewProps): JSX.Element {
   const [jobModel, setJobsModel] = useState<IJobDetailModel | null>(null);
   const [jobDefinitionModel, setJobDefinitionModel] =
     useState<IJobDefinitionModel | null>(null);
+  const [fetchError, setFetchError] = useState<string>();
 
   const trans = useTranslator('jupyterlab');
 
   const ss = new SchedulerService({});
 
   const fetchJobDetailModel = async () => {
-    const jobFromService = await ss.getJob(props.model.id);
-    const jobDetailModel = convertDescribeJobtoJobDetail(jobFromService);
-    setJobsModel(jobDetailModel);
+    try {
+      const jobFromService = await ss.getJob(props.model.id);
+      const jobDetailModel = convertDescribeJobtoJobDetail(jobFromService);
+      setJobsModel(jobDetailModel);
+    } catch (e: any) {
+      setFetchError(e.message);
+    }
   };
 
   const fetchJobDefinitionModel = async () => {
-    const definitionFromService = await ss.getJobDefinition(props.model.id);
-    const jobDefinitionModel = convertDescribeDefinitiontoDefinition(
-      definitionFromService
-    );
-    setJobDefinitionModel(jobDefinitionModel);
+    try {
+      const definitionFromService = await ss.getJobDefinition(props.model.id);
+      const jobDefinitionModel = convertDescribeDefinitiontoDefinition(
+        definitionFromService
+      );
+      setJobDefinitionModel(jobDefinitionModel);
+    } catch (e: any) {
+      setFetchError(e.message);
+    }
   };
 
-  useEffect(() => {
+  const fetchModel = () => {
     switch (props.jobsView) {
       case JobsView.JobDetail:
         fetchJobDetailModel();
@@ -85,8 +95,17 @@ export function DetailView(props: IDetailViewProps): JSX.Element {
         fetchJobDefinitionModel();
         break;
     }
+  };
+
+  useEffect(() => {
+    fetchModel();
   }, [props.jobsView, props.model, props.model.id]);
 
+  const reload = useCallback(() => {
+    setFetchError(undefined);
+    fetchModel();
+  }, []);
+
   const BreadcrumbsStyled = (
     <div role="presentation">
       <Breadcrumbs aria-label="breadcrumb">
@@ -127,7 +146,12 @@ export function DetailView(props: IDetailViewProps): JSX.Element {
             ? trans.__('Job Detail')
             : trans.__('Job Definition')}
         </Heading>
-        {props.jobsView === JobsView.JobDetail && jobModel && (
+        {fetchError && (
+          <Alert severity="error" onClose={() => setFetchError(undefined)}>
+            {fetchError}
+          </Alert>
+        )}
+        {props.jobsView === JobsView.JobDetail && (
           <JobDetail
             app={props.app}
             model={jobModel}
@@ -136,9 +160,10 @@ export function DetailView(props: IDetailViewProps): JSX.Element {
             setJobsView={props.setJobsView}
             // Extension point: optional additional component
             advancedOptions={props.advancedOptions}
+            reload={reload}
           />
         )}
-        {props.jobsView === JobsView.JobDefinitionDetail && jobDefinitionModel && (
+        {props.jobsView === JobsView.JobDefinitionDetail && (
           <JobDefinition
             app={props.app}
             model={jobDefinitionModel}
@@ -149,9 +174,10 @@ export function DetailView(props: IDetailViewProps): JSX.Element {
             editJobDefinition={props.editJobDefinition}
             // Extension point: optional additional component
             advancedOptions={props.advancedOptions}
+            reload={reload}
           />
         )}
-        {!jobModel && !jobDefinitionModel && (
+        {!jobModel && !jobDefinitionModel && !fetchError && (
           <Loading title={trans.__('Loading')} />
         )}
       </Stack>
