@@ -1,13 +1,14 @@
 import React, { useState, useMemo, useEffect } from 'react';
 import {
+  Alert,
   Button,
   Box,
   Breadcrumbs,
-  Stack,
+  CircularProgress,
   Link,
+  Stack,
   Typography,
-  InputLabel,
-  CircularProgress
+  InputLabel
 } from '@mui/material';
 
 import { Heading } from '../components/heading';
@@ -17,6 +18,9 @@ import { IUpdateJobDefinitionModel, JobsView } from '../model';
 import { useTranslator } from '../hooks';
 import { SchedulerService } from '../handler';
 import { Scheduler } from '../tokens';
+import { InputFileSnapshot } from '../components/input-file-snapshot';
+import { LabeledValue } from '../components/labeled-value';
+import { timestampLocalize } from './detail-view/job-detail';
 
 export type EditJobDefinitionProps = {
   model: IUpdateJobDefinitionModel;
@@ -32,6 +36,9 @@ function EditJobDefinitionBody(props: EditJobDefinitionProps): JSX.Element {
   const [utcOnly, setUtcOnly] = useState(false);
   const [saving, setSaving] = useState(false);
   const [fieldErrors, setFieldErrors] = useState<Scheduler.ErrorsType>({});
+  const [displayError, setDisplayError] = useState<React.ReactNode | null>(
+    null
+  );
   const hasErrors = Object.keys(fieldErrors).some(key => !!fieldErrors[key]);
 
   /**
@@ -61,16 +68,18 @@ function EditJobDefinitionBody(props: EditJobDefinitionProps): JSX.Element {
     }
 
     setSaving(true);
-    try {
-      await ss.updateJobDefinition(props.model.definitionId, {
-        schedule: props.model.schedule,
-        timezone: props.model.timezone
+    ss.updateJobDefinition(props.model.definitionId, {
+      schedule: props.model.schedule,
+      timezone: props.model.timezone,
+      input_uri: props.model.inputFileSnapshot
+    })
+      .then(() => {
+        props.showJobDefinitionDetail(props.model.definitionId);
+      })
+      .catch((e: Error) => {
+        setSaving(false);
+        setDisplayError(e.message);
       });
-      props.showJobDefinitionDetail(props.model.definitionId);
-    } catch (e) {
-      // TODO: catch any errors from backend and display them to user.
-      setSaving(false);
-    }
   };
 
   if (loading) {
@@ -79,6 +88,12 @@ function EditJobDefinitionBody(props: EditJobDefinitionProps): JSX.Element {
 
   return (
     <Stack spacing={4} maxWidth={500}>
+      {displayError && (
+        <Alert severity="error" onClose={() => setDisplayError(null)}>
+          {displayError}
+        </Alert>
+      )}
+      <InputFileSnapshot inputFileSnapshot={props.model.inputFileSnapshot} />
       <InputLabel>{trans.__('Schedule')}</InputLabel>
       <ScheduleInputs
         idPrefix=""
@@ -147,6 +162,10 @@ export function EditJobDefinition(props: EditJobDefinitionProps): JSX.Element {
           <Typography color="text.primary">{trans.__('Edit')}</Typography>
         </Breadcrumbs>
         <Heading level={1}>{trans.__('Edit Job Definition')}</Heading>
+        <LabeledValue
+          value={timestampLocalize(props.model.updateTime)}
+          label={trans.__('Job definition updated at')}
+        />
         <EditJobDefinitionBody {...props} />
       </Stack>
     </Box>
